@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 
 # creating --------------------------------------------------------------------
@@ -111,16 +111,19 @@ site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
 =head1 AUTHORS
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
-Ran Eilam C<< <eilara@cpan.org> >>
+Marcel GrE<uuml>nauer E<lt>marcel@cpan.orgE<gt>
+
+Ran Eilam E<lt>eilara@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2001 by Marcel GrE<uuml>nauer
 
+Some parts copyright 2009 - 2010 Adam Kennedy.
+
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =cut
-
